@@ -36,7 +36,7 @@ if __name__ == '__main__':
     print('starting')
     dict = {}
     dict['id'] = 1
-    dict['service_name'] = Service.FACE_DETECT
+    dict['service_name'] = Service.WEAPON_DETECTION
     dict['stream_url'] = "rtsp://admin:admin123@203.134.200.170:8000/cam/realmonitor?channel=12&subtype=0"
     dict['fps'] = 15
     dict['batch_size']=1
@@ -48,7 +48,7 @@ if __name__ == '__main__':
     # dict['databaseID']="2db2ae96-f341-4767-8e68-6ddd1c2f972b"
     service_details = dict
     
-    client = FaceDetectStreamClient(
+    client = WeaponDetectionStreamClient(
                 id=dict['id'],
                 stream=service_details['stream_url'],
                 fps=service_details['fps'],
